package client.brickblock.objects;

import client.brickblock.fwimpl.BBPlayer;

import java.io.IOException;

/**
 * <code>Powerup</code> implementation that increases
 * the size of whoever picks it up.
 *
 * @version 2.0
 * @author Martin Jarrett
 * @author Eivind Sorteberg
 */
public class SizeUp extends Powerup {
    // The address of the image for this power up
    protected static String imageAddress = "/client/brickblock/objects/size.png";

    /**
     * Constructor that creates a <code>SizeUp</code> instance
     * by calling the super constructor with the correct image
     * and properties.
     *
     * @param xPos The x-coordinate of the object.
     * @param yPos The y-coordinate of the object.
     * @param increment The increment of the power up.
     * @throws IOException If the image file is not found.
     */
    public SizeUp(int xPos, int yPos, int increment) throws IOException {
        super(imageAddress, xPos, yPos, increment);
    }

    /**
     * Activates the power up by increasing the player's
     * size for the specified time.
     *
     * @see client.brickblock.fwimpl.BBPlayer#pickupPowerup(Powerup)
     * @param player The player affected by the power up.
     */
    public void activate(BBPlayer player) {
        player.setSize(player.getSize() + increment);
    }

    /**
     * Returns the player's size to what it would have been
     * if he had not picked up the power up.
     *
     * @param player The player affected by the power up.
     */
    public void deactivate(BBPlayer player) {
        player.setSize(player.getSize() - increment);
    }

    /**
     * Returns a three letter representation for this power up
     * object.
     *
     * @return The power up name.
     */
    public String getPowerUpName() {
        return "SIZ";
    }
}
