package client.brickblock.objects;

import client.brickblock.fwimpl.BBPlayer;

import java.io.IOException;

/**
 * <code>Powerup</code> implementation that increases
 * the speed of whoever picks it up.
 *
 * @version 2.0
 * @author Martin Jarrett
 * @author Eivind Sorteberg
 */
public class SpeedUp extends Powerup {
    //The address of the image for this power up
    protected static String imageAddress = "/client/brickblock/objects/speed.png";

    /**
     * Constructor that creates a <code>SpeedUp</code> instance
     * by calling the super constructor with the correct image
     * and properties.
     *
     * @param xPos The x-coordinate of the object.
     * @param yPos The y-coordinate of the object.
     * @param increment The increment of the power up.
     * @throws IOException If the image file is not found.
     */
    public SpeedUp(int xPos, int yPos, int increment) throws IOException {
        super(imageAddress, xPos, yPos, increment);
    }

    /**
     * Activates the power up by increasing the player's
     * speed for the specified time.
     *
     * @see client.brickblock.fwimpl.BBPlayer#pickupPowerup(Powerup)
     * @param player The player affected by the power up.
     */
    public void activate(BBPlayer player) {
        player.setSpeed(player.getSpeed() + increment);
    }

    /**
     * Returns the player's speed to what it would have been
     * if he had not picked up the power up.
     *
     * @param player The player affected by the power up.
     */
    public void deactivate(BBPlayer player) {
        player.setSpeed(player.getSpeed() - increment);
    }

    /**
     * Returns a three letter representation for this power up
     * object.
     *
     * @return The power up name.
     */
    public String getPowerUpName() {
        return "SPD";
    }
}
