package client.framework.models;

/**
 * Interface allowing comparation of two objects.
 * Works similar to the <code>Comparable</code>
 * interface found in J2SE.
 *
 * @version 1.0
 * @author Eivind Sorteberg
 * @author Martin Jarrett
 */
public interface Comparable {
    /**
     * Compares the object implementing the
     * method to the object passed as input parameter.
     * Returns a negative value if the implementing
     * object is less than the input object, positive if
     * the implementing object is greater and 0 if they
     * are equal.
     *
     * @param object The object to compare to.
     * @return Positive value if the implementing object is
     * the greater, negative if it is smaller and 0 if they
     * are equal.
     */
    public int compareTo(Comparable object);
}
