package client.framework.network.parser;

/**
 * A class that represents the framework's default actions. Each action
 * consist of a three-letter string representation. These actions correspond
 * to the <code>Action</code> enum in the server framework.
 *
 * @version 1.0
 * @author Martin Jarrett
 * @author Eivind Sorteberg
 */
public class Action {
    // General actions
    public static final Action PLAYER = new Action("PLR");
    public static final Action ALIVE_REQUEST = new Action("ARQ");
    public static final Action SESSION_LIST = new Action("SSL");
    public static final Action SESSION_SELECTED = new Action("SES");
    public static final Action SETTINGS_LIST = new Action("STL");
    public static final Action SETTING_CHANGED = new Action("SET");
    public static final Action READY = new Action("RDY");
    public static final Action START = new Action("STA");
    public static final Action POSITION = new Action("POS");
    public static final Action SCORE = new Action("SCR");
    public static final Action DISCONNECT = new Action("DIS");
    public static final Action GAME_OVER = new Action("GAM");
    public static final Action TEAM = new Action("TEA");

    // The action's name
    protected String name;

    /**
     * Constructor. Should only be used locally and by extensions
     * of this class.
     *
     * @param name The name of the action.
     */
    protected Action(String name) {
        this.name = name;
    }

    /**
     * Returns the action's name.
     *
     * @return The action's name.
     */
    public String toString() {
        return this.name;
    }

    /**
     * Returns the action's name.
     * @return The action's name.
     */
    public String getName() {
        return this.name;
    }

    /**
     * Checks whether an action string is equal to this action's
     * name. Used to recognize actions sent from the server to the
     * client.
     *
     * @param action The string to compare to the action.
     * @return True if the string corresponds to the action, false if not.
     */
    public boolean equals(String action) {
        return this.getName().equals(action);
    }
}
