package client.framework.network.parser;

/**
 * A wrapper class for action messages received from and sent to the
 * server. Contains an action identifier, a sender id, and an array
 * containing values. This class is used by the MessageParser to
 * parse string messages into <code>ActionTriplet</code> objects, and
 * vice versa.
 *
 * @version 1.0
 * @author Eivind Sorteberg
 * @author Martin Jarrett
 */
public class ActionTriplet {
    private String action;
    private String sender;
    private String[][] values;

    /**
     * Creates an <code>ActionTriplet</code> object containing the specified
     * attributes.
     *
     * @param action The action identifier.
     * @param sender The sender of the message.
     * @param value An array containing values.
     */
    public ActionTriplet(String action, String sender, String[][] value) {
        this.action = action;
        this.sender = sender;
        this.values = value;
    }

    /**
     * Returns the action identifier.
     *
     * @return The action identifier.
     */
    public String getAction() {
        return this.action;
    }

    /**
     * Returns the sender id.
     *
     * @return The sender id.
     */
    public String getSender() {
        return this.sender;
    }

    /**
     * Returns the triplet's values.
     *
     * @return The triplet's values.
     */
    public String[][] getValues() {
        return this.values;
    }
}
