package client.framework.network.parser;

import java.io.IOException;

/**
 * An interface that is used to parse messages of different formats
 * into <code>ActionTriplet</code> objects, and vice versa. The format
 * of the messages should be well defined before this interface is
 * implemented, to simplify the process of implementing the methods.
 *
 * @version 1.0
 * @author Eivind Sorteberg
 * @author Martin Jarrett
 */
public interface MessageParser {
    /**
     * Takes a message in the specified format as input parameter, and
     * creates an <code>ActionTriplet</code> object based on the contents
     * of the message. If the format of the message is not as expected, an
     * <code>IOException</code> should be thrown.
     *
     * @param message The message to parse.
     * @return An <code>ActionTriplet</code> object wrapping the message's contents.
     * @throws IOException If the provided message is not in the expected format, or of the correct type.
     */
    public ActionTriplet parseMessage(Object message) throws IOException;

    /**
     * Creates a message in the specified format from an Action identifier and
     * an array of values.
     *
     * @param action The action identifier of the message.
     * @param values The values to contain in the message.
     * @return A message following the specified format.
     */
    public Object createMessage(Action action, Object[][] values);
}
