package server;

import server.testmodules.TestModule;
import server.framework.models.AbstractServer;
import server.brickblock.fwimpl.BBServer;

/**
 * The class containing the BrickBlock server's main method. The application can be started
 * in four different ways:
 *
 * [java -jar bbServer.jar]
 * Starts a regular server using port number 15 000 and UDP
 *
 * [java -jar bbServer.jar <port number> <communication protocol>]
 * Starts a regular server with the specified port number and communication protocol.
 *
 * [java -jar bbServer.jar <test type> <communication protocol>]
 * Starts a test server with the specified test type and communication protocol.
 *
 * [java -jar bbServer.jar <port number> <communication protocol> <test type>]
 * Starts a test server with the specified port number, communication protocol, and test type.
 *
 * @version 1.0
 * @author Martin Jarrett
 * @author Eivind Sorteberg
 */
public class BrickBlock {
    public static void main(String[] args) {
        int port = 15000;
        AbstractServer.CommType commType = AbstractServer.CommType.udp;
        TestModule.TestType testType = null;

        switch (args.length) {
            case 3:
                port = Integer.parseInt(args[0]);
                AbstractServer.CommType.getCommType(args[1].toLowerCase());
                testType = TestModule.TestType.getTestType(args[2].toLowerCase());
                break;
            case 2:
                try {
                    port = Integer.parseInt(args[0]);
                }
                catch (NumberFormatException e) {
                    testType = TestModule.TestType.getTestType(args[0].toLowerCase());
                }
                commType = AbstractServer.CommType.getCommType(args[1].toLowerCase());
                break;
            case 1:
                testType = TestModule.TestType.getTestType(args[0].toLowerCase());
                break;
        }
        new BBServer(port, commType, testType);
    }
}
