package server.brickblock.fwimpl;

import server.framework.models.AbstractServer;
import server.framework.models.AbstractSession;
import server.framework.threads.Event;
import server.testmodules.TestModule;

/**
 * The BrickBlock implementation of the <code>AbstractSession</code> model.
 * Creates a <code>BBEventHandler</code> instance, and forwards game events
 * to this event handler.
 *
 * @author Eivind Sorteberg
 */
public class BBSession extends AbstractSession<BBPlayer, BBEventHandler> {
    /**
     * Creates a <code>BBSession</code> object by calling the parent class'
     * constructor. Does not add any extra content to the object.
     *
     * @param server The server to which the session belongs.
     * @param testtype The test type, if any.
     */
    public BBSession(AbstractServer<BBSession, BBPlayer> server, TestModule.TestType testtype) {
        super(server, testtype);
    }

    /**
     * Creates a <code>BBEventHandler</code> instance.
     * @return A <code>BBEventHandler</code> instance.
     */
    protected BBEventHandler createEventHandler() {
        return new BBEventHandler(this);
    }

    /**
     * Forwards game specific events to the event handler.
     *
     * @param event The event.
     * @param sender The player that caused the event.
     * @param values Values related to the event.
     */
    public void notifyAboutEventOccured(Event event, BBPlayer sender, Object[] values) {
        if(this.eventHandler != null){
            this.eventHandler.fireEventOccured(sender, event, values);
        }
    }
}
