package server.brickblock.objects;

import server.brickblock.fwimpl.BBPlayer;

/**
 * <code>Powerup</code> implementation that increases
 * the size of whoever picks it up.
 *
 * @author Martin Jarrett
 * @author Eivind Sorteberg
 * @version 1.0
 */
public class SizeUp extends Powerup {
    /**
     * Constructor that creates a <code>SizeUp</code> instance
     * by calling the super constructor with the correct image
     * and properties.
     *
     * @param xPos     The x-coordinate of the object.
     * @param yPos     The y-coordinate of the object.
     * @param duration How long the object lasts.
     */
    public SizeUp(int xPos, int yPos, int duration) {
        super(xPos, yPos, duration);
    }

    /**
     * Activates the power up by increasing the player's
     * size for the specified time.
     *
     * @param player The player affected by the power up.
     */
    public void activate(BBPlayer player) {
        player.setSize(player.getSize() + getIncrement());
    }

    /**
     * Returns the player's size to what it would have been
     * if he had not picked up the power up.
     *
     * @param player The player affected by the power up.
     */
    public void deactivate(BBPlayer player) {
        player.setSize(player.getSize() - getIncrement());
    }

    /**
     * Returns the player attribute that is affected by the power up
     * object, i.e.size.
     *
     * @param player A <code>BBPlayer</code> object.
     * @return The size attribute.
     */
    public Object getAffectedAttribute(BBPlayer player) {
        return player.getSize();
    }

    /**
     * Returns a three letter String representation of the power up object.
     *
     * @return The name of the power up object
     */
    public String getName() {
        return "SIZ";
    }

    /**
     * Returns the power up's increment value, i.e. how much the
     * player's affected attribute is incremented when picking up the power up.
     *
     * @return The power up's increment value.
     */
    public int getIncrement() {
        return 5;
    }
}
