package server.framework;

import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * Utility class used to print server info to the console.
 *
 * @version 1.0
 * @author Martin Jarrett
 * @author Eivind Sorteberg
 */
public abstract class Utils {
    /**
     * @return The current time in the format "HH:mm:ss [yyyy-MM-dd]".
     */
    public static String getCurrentTime() {
        Date date = new Date();
        SimpleDateFormat format = new SimpleDateFormat("HH:mm:ss '['yyyy-MM-dd']'");
        return format.format(date);
    }

    /**
     * Method that prints the provided information with a timestamp, in the
     * format "<time>: <info>". If the error flag is set to true, the
     * <code>System.err.println()</code> method is used.
     *
     * @param info The message to print.
     * @param error If true, the method prints an error message, if not, <code>System.out</code> is used.
     */
    public static void printTimeStampedInfo(String info, boolean error) {
        if (!error) System.out.println(getCurrentTime() + ": " + info);
        else System.err.println(getCurrentTime() + ": " + info);
    }

    /**
     * Prints time stamped info using <code>System.out</code>.
     *
     * @see server.framework.Utils#printTimeStampedInfo(String, boolean)
     * @param info The message to print.
     */
    public static void printTimeStampedInfo(String info) {
        printTimeStampedInfo(info, false);
    }
}
