package server.framework.gui;

import server.framework.models.AbstractSession;
import server.framework.models.Setting;

import javax.swing.*;
import java.awt.*;
import java.util.HashMap;

/**
 * The <code>SettingsPanel</code> displays information about
 * the session's settings. This information is reloaded whenever
 * a change in the settings occurs.
 *
 * @author Martin Jarrett
 * @author Eivind Sorteberg
 * @version 1.0
 */
public class SettingsPanel extends JPanel {

    // The session which the <code>SettingsPanel</code> belongs to.
    private AbstractSession session;

    /**
     * Creates a <code>SettingsPanel</code> object with the specified attributes
     * and calls the inialize method.
     *
     * @param session The session the SettingsPanel belongs to.
     */
    public SettingsPanel(AbstractSession session) {
        this.session = session;
        this.initialize();
    }

    /**
     * Sets the size of the panel.
     */
    private void initialize() {
        this.setPreferredSize(new Dimension(200, 200));
    }

    /**
     * Used to paint the panel according to the desired layout.
     *
     * @param g The Graphics object used to paint the panel.
     */
    public void paint(Graphics g) {
        super.paint(g);

        Graphics2D g2d = (Graphics2D)g;
        int posY = 10;
        int lineHeight = 15;

        HashMap<Setting, Object> settings = this.session.getSettings().getSettings();
        for (Setting setting : settings.keySet()) {
            int posX = 15;
            g2d.drawString(setting.toString(), posX, posY);
            posX = 160;
            g2d.drawString(settings.get(setting).toString(), posX, posY);
            posY += lineHeight;
        }
    }

    /**
     * Used to update the gui when a settings has changed.
     * The panel repaints to show the lateste settings.
     */
    public void fireSettingsListChanged() {
        this.repaint();
    }
}
