package server.framework.models;

/**
 * Enum that specifies the settings used in the game. When settings
 * are to be added, the contents of this enum must be extended.
 *
 * @version 1.0
 * @author Martin Jarrett
 * @author Eivind Sorteberg
 */
public enum Setting {
    score("Score limit"),
    time("Time limit"),
    teams("Teams enabled"),
    nof_players("Players");

    // The name of the setting (shown in the client's settings list)
    private String text;

    /**
     * Creates a setting with the specified text.
     *
     * @param text The name of the setting.
     */
    private Setting(String text) {
        this.text = text;
    }

    /**
     * @return The name of the setting.
     */
    public String getText() {
        return this.text;
    }

    /**
     * Used to find the enum with the specified name.
     *
     * @param name The name of the setting.
     * @return The setting that corresponds to the specified name.
     */
    public static Setting getSetting(String name) {
        for (Setting setting : values()) {
            if (setting.getText().equals(name)) {
                return setting;
            }
        }
        return null;
    }

    /**
     * @return The name of the setting.
     */
    public String toString() {
        return this.getText();
    }
}

