package server.framework.network.parser;

/**
 * This enum contains the actions specified for both the
 * framework and for games implementing the framework. New
 * need to be added to this enum.
 *
 * Each enum contain a three-letter description corresponding
 * to the action's specification.
 *
 * @version 1.0
 * @author Martin Jarrett
 * @author Eivind Sorteberg
 */
public enum Action {
    player("PLR"),
    alive_request("ARQ"),
    position("POS"),
    ready("RDY"),
    start("STA"),
    disconnect("DIS"),
    score("SCR"),
    setting_changed("SET"),
    session_selected("SES"),
    game_over("GAM"),
    setting_list("STL"),
    session_list("SSL"),
    team("TEA"),
    empty_message(""),

    trap_added("TRA"),
    powerup_added("PUA"),
    powerup_removed("PUR"),
    powerup_inactive("PIN"),
    force("FRC");

    // The name of the action
    private final String name;

    /**
     * Creates a new action. Can only be called within this enum.
     *
     * @param action The enum's value.
     */
    Action(String action) {
        this.name = action;
    }

    /**
     * @return The three-letter action identificator.
     */
    public String getName() {
        return this.name;
    }

    /**
     * Returns the enum corresponding to the specified
     * three-letter identifier.
     *
     * @param name The action identifier.
     * @return The action corresponding to the identifier.
     */
    public static Action getActionObject(String name) {
        for (Action action : values()) {
            if (action.getName().equals(name)) {
                return action;
            }
        }
        return null;
    }
}
