package server.framework.network.parser;

import java.util.Arrays;

/**
 * A wrapper class that consist of an Action enum and
 * the action's corresponding values.
 *
 * @version 1.0
 * @author Martin Jarrett
 * @author Eivind Sorteberg
 */
public class ActionPair {
    private Action action;
    private String[][] values;

    /**
     * Creates a new wrapper object with the specified contents.
     *
     * @param action The action identifier.
     * @param values The action's corresponding values.
     */
    public ActionPair(Action action, String[][] values) {
        this.action = action;
        this.values = values;
    }

    /**
     * @return The wrapper's action.
     */
    public Action getAction() {
        return action;
    }

    /**
     * @return The wrapper's values.
     */
    public String[][] getValues() {
        return values;
    }

    /**
     * Sets the values of the wrapper to the specified values.
     *
     * @param values The values corresponding to the wrapper's action.
     */
    public void setValues(String[][] values) {
        this.values = values;
    }

    /**
     * @return A string representation of the wrapper, corresponding to the specified message format.
     */
    public String toString() {
        String ret = action + ":";
        for (String[] value : values) {
            ret += " " + Arrays.toString(value);
        }
        return ret;
    }
}
