package server.framework.network.parser;

import server.framework.models.AbstractPlayer;

/**
 * An interface that is used to parse messages of different formats
 * into <code>ActionPair</code> objects, and vice versa. The format
 * of the messages should be well defined before this interface is
 * implemented, to simplify the process of implementing the methods.
 *
 * @version 1.0
 * @author Eivind Sorteberg
 * @author Martin Jarrett
 */
public interface MessageParser<T> {
    /**
     * Takes a message in the specified format as input parameter, and
     * creates an <code>ActionPair</code> object based on the contents
     * of the message.
     *
     * @param message The message to parse.
     * @return An <code>ActionPair</code> object wrapping the message's contents.
     */
    public ActionPair parseMessage(T message);

    /**
     * Creates a message in the specified format from an Action identifier,
     * an array of values, and a sender.
     *
     * @param action The action identifier of the message.
     * @param values The values to contain in the message.
     * @param sender The sender of the action message.
     * @return A message following the specified format.
     */
    public T createMessage(Action action, Object[][] values, AbstractPlayer sender);
}
